#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc
version: 1.17.0.3
id: pandoc-1.17.0.3-a12df7a7745e5ea4de39fe36e7ff7b76
key: pando_Ic8iW0y3niIE97JSXnLXg8
license: GPL
copyright: (c) 2006-2016 John MacFarlane
maintainer: John MacFarlane <jgm@berkeley.edu>
stability: alpha
homepage: http://pandoc.org
synopsis: Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. It can read several dialects of Markdown and
    (subsets of) HTML, reStructuredText, LaTeX, DocBook,
    MediaWiki markup, TWiki markup, Haddock markup, OPML,
    Emacs Org-Mode, txt2tags, Word Docx, ODT, and Textile, and
    it can write Markdown, reStructuredText, XHTML, HTML 5,
    LaTeX, ConTeXt, DocBook, OPML, TEI, OpenDocument, ODT,
    Word docx, RTF, MediaWiki, DokuWiki, Textile, groff man
    pages, plain text, Emacs Org-Mode, AsciiDoc, Haddock markup,
    EPUB (v2 and v3), FictionBook2, InDesign ICML, and several
    kinds of HTML/javascript slide shows (S5, Slidy, Slideous,
    DZSlides, reveal.js).
    .
    In contrast to most existing tools for converting Markdown
    to HTML, pandoc has a modular design: it consists of a set of
    readers, which parse text in a given format and produce a
    native representation of the document, and a set of writers,
    which convert this native representation into a target
    format. Thus, adding an input or output format requires
    only adding a reader or writer.
category: Text
author: John MacFarlane <jgm@berkeley.edu>
exposed: True
exposed-modules:
    Text.Pandoc Text.Pandoc.Options Text.Pandoc.Pretty
    Text.Pandoc.Shared Text.Pandoc.MediaBag Text.Pandoc.Error
    Text.Pandoc.Readers.HTML Text.Pandoc.Readers.LaTeX
    Text.Pandoc.Readers.Markdown Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.MediaWiki Text.Pandoc.Readers.RST
    Text.Pandoc.Readers.Org Text.Pandoc.Readers.DocBook
    Text.Pandoc.Readers.OPML Text.Pandoc.Readers.TeXMath
    Text.Pandoc.Readers.Textile Text.Pandoc.Readers.Native
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.TWiki
    Text.Pandoc.Readers.Txt2Tags Text.Pandoc.Readers.Docx
    Text.Pandoc.Readers.Odt Text.Pandoc.Readers.EPUB
    Text.Pandoc.Writers.Native Text.Pandoc.Writers.Docbook
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.HTML
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.LaTeX
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.Haddock Text.Pandoc.Writers.RST
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.AsciiDoc
    Text.Pandoc.Writers.Custom Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.RTF Text.Pandoc.Writers.ODT
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.EPUB
    Text.Pandoc.Writers.FB2 Text.Pandoc.Writers.TEI Text.Pandoc.PDF
    Text.Pandoc.UTF8 Text.Pandoc.Templates Text.Pandoc.XML
    Text.Pandoc.SelfContained Text.Pandoc.Process Text.Pandoc.CSS
hidden-modules: Text.Pandoc.Readers.Docx.Lists
                Text.Pandoc.Readers.Docx.Combine Text.Pandoc.Readers.Docx.Parse
                Text.Pandoc.Readers.Docx.Fonts Text.Pandoc.Readers.Docx.Util
                Text.Pandoc.Readers.Docx.StyleMap Text.Pandoc.Readers.Odt.Base
                Text.Pandoc.Readers.Odt.Namespaces
                Text.Pandoc.Readers.Odt.StyleReader
                Text.Pandoc.Readers.Odt.ContentReader
                Text.Pandoc.Readers.Odt.Generic.Fallible
                Text.Pandoc.Readers.Odt.Generic.SetMap
                Text.Pandoc.Readers.Odt.Generic.Utils
                Text.Pandoc.Readers.Odt.Generic.Namespaces
                Text.Pandoc.Readers.Odt.Generic.XMLConverter
                Text.Pandoc.Readers.Odt.Arrows.State
                Text.Pandoc.Readers.Odt.Arrows.Utils Text.Pandoc.Writers.Shared
                Text.Pandoc.Asciify Text.Pandoc.MIME Text.Pandoc.Emoji
                Text.Pandoc.Parsing Text.Pandoc.UUID Text.Pandoc.ImageSize
                Text.Pandoc.Slides Text.Pandoc.Highlighting Text.Pandoc.Compat.Time
                Text.Pandoc.Compat.Except Text.Pandoc.Compat.TagSoupEntity
                Text.Pandoc.Compat.Directory Text.Pandoc.Compat.Monoid Paths_pandoc
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
data-dir: /usr/share/pandoc
hs-libraries: HSpandoc-1.17.0.3-Ic8iW0y3niIE97JSXnLXg8
depends:
    HTTP-4000.3.3-e80abaf8bcce3e49baa17e1fe8d694c7
    JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
    SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cmark-0.5.2-f48a7256a8c75efe8918f0ce1d08f0cd
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
    filemanip-0.3.6.3-6a0a490bedb1f674368cb208047d68cb
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    haddock-library-1.2.1-51a4bfa148b95520f3c56461f9e3c4f2
    highlighting-kate-0.6.2-78975d33e6a60b626b8bbe418bb316e1
    hslua-0.4.1-5acb63b51e4a9d39e9aa4a0ad9006234
    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
    http-client-tls-0.2.2-05f6aae0a8612df864dc61b6b7405a00
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
    temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
    texmath-0.8.5.1-12fde9597135cf71aeccebd23ab95779
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
    zip-archive-0.3-2c98cfc50f306ecd4e01363be7a8d981
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html: /usr/share/doc/pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
